@@ -76,37 +76,17 @@ def main():
     else:
         print('Warning: destination directory not existing; creating it.')
         os.mkdir(options.dest_dir)
-
+        
     for f in options.paths:
         if options.want_info:
             xf = xsq.XSQFile(f)
-            ats = (('tagdetails', lambda x: ', '.join(x.tags)), 
-                   ('lanenumber', lambda x: x[0]),
-                   ('hdfversion', lambda x: x[0]),
-                   ('fileversion',lambda x: x[0]),
-                   ('sequencingsamplename', lambda x: x[0]),
-                   ('sequencingsampledescription', lambda x: x[0]),
-                   ('runname',lambda x: x[0]))
-            try:
-                mtd = xf.run_metadata
-                for at, fun in ats:
-                    sys.stdout.write(getattr(xsq.XSQRunMetadata, 
-                                             at).__doc__)
-                    sys.stdout.write(': ')
-                    tmp = getattr(mtd, at)
-                    #import pdb; pdb.set_trace()
-                    sys.stdout.write(str(fun(tmp)))
-                    sys.stdout.write('\n')
-                    sys.stdout.flush()
-            except KeyError, ke:
-                for at, fun in ats:
-                    sys.stdout.write(getattr(xsq.XSQRunMetadata, 
-                                             at).__doc__)
-                    sys.stdout.write(': ')
-                    sys.stdout.write('NA')
-                    sys.stdout.write('\n')
-                    sys.stdout.flush()
-                sys.stdout.write('Error: Missing run meta-data in the file\n')
+            xsqinfo = xsq.XSQInfo.fromxsqfile_toordict(xf)
+            for field, value in xsqinfo.iteritems():
+                sys.stdout.write(field)
+                sys.stdout.write(': ')
+                sys.stdout.write(value)
+                sys.stdout.write('\n')
+                sys.stdout.flush()
             xf.close()
 
         if options.to_csfasta:
